#
# spec file for package maven-invoker-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with  groovy
Name:           maven-invoker-plugin
Version:        3.9.0
Release:        1.1
Summary:        Maven Invoker Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-invoker-plugin/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugins/%{name}/%{version}/%{name}-%{version}-source-release.zip
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(javax.inject:javax.inject)
BuildRequires:  mvn(org.apache-extras.beanshell:bsh)
BuildRequires:  mvn(org.apache.maven.doxia:doxia-sink-api)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-api)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-impl)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-api)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-util)
BuildRequires:  mvn(org.apache.maven.shared:maven-invoker)
BuildRequires:  mvn(org.apache.maven.shared:maven-script-interpreter) >= 1.3
BuildRequires:  mvn(org.apache.maven.shared:maven-shared-utils)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven:maven-settings)
BuildRequires:  mvn(org.apache.maven:maven-settings-builder)
BuildRequires:  mvn(org.codehaus.modello:modello-maven-plugin)
BuildRequires:  mvn(org.codehaus.plexus:plexus-i18n)
BuildRequires:  mvn(org.codehaus.plexus:plexus-interpolation)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.codehaus.plexus:plexus-xml)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildArch:      noarch
%if %{with groovy}
# runtime dependencies, but must be there
BuildRequires:  mvn(org.apache.groovy:groovy)
BuildRequires:  mvn(org.apache.groovy:groovy-bom:pom:)
BuildRequires:  mvn(org.apache.groovy:groovy-json)
BuildRequires:  mvn(org.apache.groovy:groovy-xml)
%endif

%description
The Maven Invoker Plugin is used to run a set of Maven projects. The plugin
can determine whether each project execution is successful, and optionally
can verify the output generated from a given project execution.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q

%pom_remove_plugin :maven-enforcer-plugin

%if %{without groovy}
%pom_remove_dep 'org.apache.groovy:'
%endif

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Tue Dec 10 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.9.0
  * New Feature
    + MINVOKER-374: Ability to skip project collection
  * Tasks
    + MINVOKER-375: Bump org.apache.groovy:groovy-bom from 4.0.23
    to 4.0.24
    + MINVOKER-376: Bump commons-io:commons-io from 2.17.0 to 2.18.0
* Tue Oct 29 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.8.1
  * Dependency upgrade
    + MINVOKER-371: Upgrade to Doxia 2.0.0 GA Stack
* Wed Oct  2 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade tu upstream version 3.8.0
- Changes of version 3.3.0:
  * Breaking changes
    + MINVOKER-304: Use only common groovy modules - xml, json
    + MINVOKER-281: java 8 as minimum
  * New features and improvements
    + MINVOKER-269: Execute forked Maven in quiet mode
    + MINVOKER-288: Failed setup job cause skip rest of jobs
    + MINVOKER-303: Print build summary at the end after logs
    + MINVOKER-294: Allow override mavenExecutable in
    invoker.properties
  * Bug Fixes
    + MINVOKER-299: fix filtering-extensions test
    + MINVOKER-297: NPE when non-existing Maven Home
    + Fix Modello namespace
    + MINVOKER-273: Environment variable with empty value
- Changes of version 3.4.0:
  * New features and improvements
    + MINVOKER-312: change to groovy groupId org.apache.groovy and
    bump version to 4.x support jdk19
    + MINVOKER-289: Support for shared invoker's Update-Snapshots
    Flag
  * Bug Fixes
    + MINVOKER-306: Fixed bug if only exclude-patterns specified
- Changes of version 3.5.0:
  * Bug
    + MINVOKER-318: invoker install can not resolve test
    dependencies if they overlap with runtime deps
    + MINVOKER-319: Invoker Install fail with Maven 4.0.0-alpha-4
    + MINVOKER-323: DefaultVersionResolver is inflicting
    ArtifactNotFoundException for classifiers with SNAPSHOT
    version
  * Improvement
    + MINVOKER-313: Get rid of maven-artifact-transfer
  * Task
    + MINVOKER-324: Fix Temporary File Information Disclosure
    Vulnerability
- Changes of version 3.5.1:
  * Bug Fixes
    + MINVOKER-333: Artifact should be installed once
    + MINVOKER-330: Allow relative path for mavenExecutable
    + MINVOKER-328: Skip install artifacts with the same source and
    target path
- Changes of version 3.6.0
  * Sub-task
    + MINVOKER-347: Document upcoming report file name change
  * Bug
    + MINVOKER-340: AbstractInvokerMojo/InvokerReport subclasses are
    not thread-safe due to use of DecimalFormat
  * Improvement
    + MINVOKER-341: Make elapsed time field type consistent with
    Maven Surefire
    + MINVOKER-342: Use ChoiceFormat to selectively render elapsed
    time in AbstractInvokerMojo
    + MINVOKER-345: Use ChoiceFormat to selectively render
    percentage and elapsed time in InvokerReportRenderer
  * Task
    + MINVOKER-343: Make elapsed time rendering consistent with
    Maven Surefire
    + MINVOKER-344: Move reporting rendering logic into a
    ReportRenderer class
- Changes of version 3.6.1
  * New features and improvements
    + MINVOKER-352: Remove usage of commons-lang3
- Changes of version 3.7.0
  * New features and improvements
    + MINVOKER-307: Support @{..} syntax in mavenOpts
    + MINVOKER-365: Allow to pre-build script to set user properties
    + MINVOKER-366: Require Maven 3.6.3
    + MINVOKER-364: Rename invoker.systemPropertiesFile to
    invoker.userPropertiesFile
  * Bug Fixes
    + MINVOKER-351: Escape special xml character in junit report
    + MINVOKER-335: Use selector script for preparing test with
    symlinks
    + MINVOKER-336: Create empty .mvn directory in cloned projects
    + MINVOKER-335: Preserve symlinks for copied files
    + MINVOKER-337: Exclude plexus-container-default and o.a.maven
    from runtime dependencies
- Changes of version 3.8.0
  * New features and improvements
    + MINVOKER-368: Filter artifacts by scope before resolving in
    install
    + MINVOKER-354: Upgrade to Doxia 2.0.0 Milestone Stack
* Mon Sep 25 2023 Fridrich Strba <fstrba@suse.com>
- Remove dependency on maven2
* Thu Apr 28 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.2.2
  * Changes:
  * MINVOKER-191: "Artifact is not fully assembled" error with
    maven-invoker-plugin in parallel build
  * MINVOKER-224: Unable to set cloneProjectsTo to null
  * MINVOKER-196: Support for JUnit report style
  * MINVOKER-249: InstallMojo extraArtifacts are always
    downloaded (optionally local repo must checked first)
  * MINVOKER-174: add a property to configure build order
  * MINVOKER-251: Allow options parallelThreads depends on
    available cores
  * MINVOKER-195: Fast Build - mergeUserSettings and mirrors, docs
  * MINVOKER-250: streamLogsOnFailures
  * MINVOKER-268: Introduce updateOnly parameter to AbstractInvokerMojo
  * fixes build with maven-script-interpreter 1.3
* Fri Nov 22 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.2.1
* Sat Apr  6 2019 Jan Engelhardt <jengelh@inai.de>
- Add Group: line for documentation.
* Fri Apr  5 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-invoker-plugin 1.10
